﻿#region ファイル説明
//-----------------------------------------------------------------------------
// AnimationClip.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//
// このソースコードはAppHubのSkinned Modelコードを翻訳しただけ
//
// http://create.msdn.com/en-US/education/catalog/sample/skinned_model
//-----------------------------------------------------------------------------
#endregion

#region Using ステートメント

using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework.Content;

#endregion

namespace SkinnedModel
{
    /// <summary>
    /// Microsoft.Xna.Framework.Content.Pipeline.Graphics.AnimationContentに
    /// 相当する情報を持つアニメーションクリップ
    /// ひとつのアニメーションに必要な複数キーフレーム情報を持つ
    /// </summary>
    public class AnimationClip
    {
        /// <summary>
        /// 新しいアニメーションクリップの生成
        /// </summary>
        public AnimationClip(TimeSpan duration, List<Keyframe> keyframes)
        {
            Duration = duration;
            Keyframes = keyframes;
        }

        /// <summary>
        /// XNBシリアライザー用のプライベートコンストラクタ
        /// </summary>
        private AnimationClip()
        {
        }

        /// <summary>
        /// アニメーション期間の取得
        /// </summary>
        [ContentSerializer]
        public TimeSpan Duration { get; private set; }

        /// <summary>
        /// 全ボーンの全キーフレームをもつリストの取得
        /// キーフレームは時間順に並べ替えてある
        /// </summary>
        [ContentSerializer]
        public List<Keyframe> Keyframes { get; private set; }
    }
}
