﻿#region ファイル説明
//-----------------------------------------------------------------------------
// Keyframe.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//
// このソースコードはAppHubのSkinned Modelコードを翻訳しただけ
//
// http://create.msdn.com/en-US/education/catalog/sample/skinned_model
//-----------------------------------------------------------------------------
#endregion

#region Using ステートメント

using System;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;

#endregion

namespace SkinnedModel
{
    /// <summary>
    /// キーフレーム、時間とボーンの変換行列のペア
    /// </summary>
    public class Keyframe
    {
        /// <summary>
        /// キーフレームオブジェクトの生成
        /// </summary>
        public Keyframe(int bone, TimeSpan time, Matrix transform)
        {
            Bone = bone;
            Time = time;
            Transform = transform;
        }


        /// <summary>
        /// XNBシリアライザー用のプライベートコンストラクタ
        /// </summary>
        private Keyframe()
        {
        }


        /// <summary>
        /// ボーンインデックスの取得
        /// </summary>
        [ContentSerializer]
        public int Bone { get; private set; }


        /// <summary>
        /// このキーフレームが設定されたアニメーション開始時点からの経過時間の取得
        /// </summary>
        [ContentSerializer]
        public TimeSpan Time { get; private set; }


        /// <summary>
        /// このキーフレームの変換行列の取得
        /// </summary>
        [ContentSerializer]
        public Matrix Transform { get; private set; }
    }
}
