﻿#region ファイル説明
//-----------------------------------------------------------------------------
// SkinningData.cs
//
// Microsoft XNA Community Game Platform
// Copyright (C) Microsoft Corporation. All rights reserved.
//
// このソースコードはAppHubのSkinned Modelコードを翻訳しただけ
//
// http://create.msdn.com/en-US/education/catalog/sample/skinned_model
//-----------------------------------------------------------------------------
#endregion

#region Using ステートメント

using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;

#endregion

namespace SkinnedModel
{
    /// <summary>
    /// スキンアニメーションに必要な情報をもつSkinningDataクラス
    /// 通常、ModelクラスのTagプロパティに設定されている
    /// </summary>
    public class SkinningData
    {
        /// <summary>
        /// 新しいSkinningDataの生成
        /// </summary>
        public SkinningData(Dictionary<string, AnimationClip> animationClips,
                            List<Matrix> bindPose, List<Matrix> inverseBindPose,
                            List<int> skeletonHierarchy)
        {
            AnimationClips = animationClips;
            BindPose = bindPose;
            InverseBindPose = inverseBindPose;
            SkeletonHierarchy = skeletonHierarchy;
        }


        /// <summary>
        /// XNBシリアライザー用のプライベートコンストラクタ
        /// </summary>
        private SkinningData()
        {
        }


        /// <summary>
        /// アニメーションクリップ辞書テーブルの取得
        /// アニメーションクリップは"Walk", "Run",
        /// "JumpReallyHigh"といった名前で取得できる
        /// </summary>
        [ContentSerializer]
        public Dictionary<string, AnimationClip> AnimationClips { get; private set; }


        /// <summary>
        /// 各ボーンのバインドポーズ行列の取得
        /// </summary>
        [ContentSerializer]
        public List<Matrix> BindPose { get; private set; }


        /// <summary>
        /// 各ボーンのバインドポーズ逆行列の取得
        /// </summary>
        [ContentSerializer]
        public List<Matrix> InverseBindPose { get; private set; }


        /// <summary>
        /// 各ボーンの親のボーンのインデックス情報を取得する
        /// </summary>
        [ContentSerializer]
        public List<int> SkeletonHierarchy { get; private set; }
    }
}
